@@ -96,8 +96,7 @@ class AioEndpoint(Endpoint):
                 'ResponseMetadata' in success_response[1]:
             # We want to share num retries, not num attempts.
             total_retries = attempts - 1
-            success_response[1]['ResponseMetadata']['RetryAttempts'] = \
-                total_retries
+            success_response[1]['ResponseMetadata']['RetryAttempts'] = total_retries
         if exception is not None:
             raise exception
         else:
