@@ -6,10 +6,28 @@ from botocore.exceptions import PartialCredentialsError
 from .client import AioClientCreator, AioBaseClient
 from .hooks import AioHierarchicalEmitter
 from .parsers import AioResponseParserFactory
-from .signers import add_generate_presigned_url, add_generate_presigned_post
+from .signers import add_generate_presigned_url, add_generate_presigned_post, \
+    add_generate_db_auth_token
+from .handlers import inject_presigned_url_ec2, inject_presigned_url_rds
+from botocore.handlers import \
+    inject_presigned_url_rds as boto_inject_presigned_url_rds, \
+    inject_presigned_url_ec2 as boto_inject_presigned_url_ec2
+from botocore.signers import \
+    add_generate_presigned_url as boto_add_generate_presigned_url, \
+    add_generate_presigned_post as boto_add_generate_presigned_post, \
+    add_generate_db_auth_token as boto_add_generate_db_auth_token
 from .credentials import create_credential_resolver, AioCredentials
 
 
+_HANDLER_MAPPING = {
+    boto_inject_presigned_url_ec2: inject_presigned_url_ec2,
+    boto_inject_presigned_url_rds: inject_presigned_url_rds,
+    boto_add_generate_presigned_url: add_generate_presigned_url,
+    boto_add_generate_presigned_post: add_generate_presigned_post,
+    boto_add_generate_db_auth_token: add_generate_db_auth_token,
+}
+
+
 class ClientCreatorContext:
     def __init__(self, coro):
         self._coro = coro
@@ -33,9 +51,11 @@ class AioSession(Session):
 
         super().__init__(session_vars, event_hooks, include_builtin_handlers, profile)
 
-        # Register our own handlers
-        self.register('creating-client-class', add_generate_presigned_url)
-        self.register('creating-client-class.s3', add_generate_presigned_post)
+    def register(self, event_name, handler, unique_id=None,
+                 unique_id_uses_count=False):
+        handler = _HANDLER_MAPPING.get(handler, handler)
+
+        return super().register(event_name, handler, unique_id, unique_id_uses_count)
 
     def _register_response_parser_factory(self):
         self._components.register_component('response_parser_factory',
@@ -136,9 +156,9 @@ class AioSession(Session):
             api_version=api_version
         )
         service_id = EVENT_ALIASES.get(service_name, service_name)
-        self._events.emit('service-data-loaded.%s' % service_id,
-                          service_data=service_data,
-                          service_name=service_name, session=self)
+        await self._events.emit('service-data-loaded.%s' % service_id,
+                                service_data=service_data,
+                                service_name=service_name, session=self)
         return service_data
 
     async def get_available_regions(self, service_name, partition_name='aws',
